@@ -6,7 +6,7 @@ import time
 import random
 import json
 import requests
-from gooblerpkg.Config import colors
+from Config import colors
 
 ###################
 ### Goobler 2022 ##
